@@ -5,9 +5,9 @@ import (
 	"regexp"
 	"strings"
 
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/debug"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
-	"github.com/tfsec/tfsec/internal/app/tfsec/debug"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
 )
@@ -76,6 +76,36 @@ func (attr *HCLAttribute) Name() string {
 	return attr.hclAttribute.Name
 }
 
+func (attr *HCLAttribute) ValueAsStrings() []string {
+	return getStrings(attr.hclAttribute.Expr, attr.ctx)
+}
+
+func getStrings(expr hcl.Expression, ctx *hcl.EvalContext) []string {
+	var results []string
+	switch t := expr.(type) {
+	case *hclsyntax.TupleConsExpr:
+		for _, expr := range t.Exprs {
+			results = append(results, getStrings(expr, ctx)...)
+		}
+	case *hclsyntax.FunctionCallExpr, *hclsyntax.ScopeTraversalExpr,
+		*hclsyntax.ConditionalExpr:
+		subVal, err := t.Value(ctx)
+		if err == nil && subVal.Type() == cty.String {
+			results = append(results, subVal.AsString())
+		}
+	case *hclsyntax.LiteralValueExpr:
+		if t.Val.Type() == cty.String {
+			results = append(results, t.Val.AsString())
+		}
+	case *hclsyntax.TemplateExpr:
+		// walk the parts of the expression to ensure that it has a literal value
+		for _, p := range t.Parts {
+			results = append(results, getStrings(p, ctx)...)
+		}
+	}
+	return results
+}
+
 func (attr *HCLAttribute) listContains(val cty.Value, stringToLookFor string, ignoreCase bool) bool {
 	valueSlice := val.AsValueSlice()
 	for _, value := range valueSlice {
@@ -84,6 +114,9 @@ func (attr *HCLAttribute) listContains(val cty.Value, stringToLookFor string, ig
 			valueMap := value.AsValueMap()
 			stringToTest = valueMap["key"]
 		}
+		if !value.IsKnown() {
+			continue
+		}
 		if ignoreCase && containsIgnoreCase(stringToTest.AsString(), stringToLookFor) {
 			return true
 		}
@@ -97,13 +130,11 @@ func (attr *HCLAttribute) listContains(val cty.Value, stringToLookFor string, ig
 func (attr *HCLAttribute) mapContains(checkValue interface{}, val cty.Value) bool {
 	switch t := checkValue.(type) {
 	case map[interface{}]interface{}:
-
 		for k, v := range t {
-
 			valueMap := val.AsValueMap()
 			for key, value := range valueMap {
 				rawValue := getRawValue(value)
-				if key == k && rawValue == v {
+				if key == k && evaluate(v, rawValue) {
 					return true
 				}
 			}
