@@ -6,23 +6,23 @@ import (
 	"io/ioutil"
 	"strings"
 
-	"github.com/tfsec/tfsec/pkg/result"
+	"github.com/aquasecurity/tfsec/pkg/result"
 
-	"github.com/tfsec/tfsec/pkg/severity"
+	"github.com/aquasecurity/tfsec/pkg/severity"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/metrics"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/metrics"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/parser"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/parser"
 
 	"github.com/liamg/clinch/terminal"
 	"github.com/liamg/tml"
 )
 
 var severityFormat = map[severity.Severity]string{
-	severity.Info:    tml.Sprintf("<white>%s</white>", severity.Info),
-	severity.Warning: tml.Sprintf("<yellow>%s</yellow>", severity.Warning),
-	severity.Error:   tml.Sprintf("<red>%s</red>", severity.Error),
-	"":               tml.Sprintf("<white>%s</white>", severity.Info),
+	severity.Low:    tml.Sprintf("<white>%s</white>", severity.Low),
+	severity.Medium: tml.Sprintf("<yellow>%s</yellow>", severity.Medium),
+	severity.High:   tml.Sprintf("<red>%s</red>", severity.High),
+	"":              tml.Sprintf("<white>%s</white>", severity.Low),
 }
 
 func FormatDefault(_ io.Writer, results []result.Result, _ string, options ...FormatterOption) error {
