@@ -6,9 +6,9 @@ import (
 
 	"github.com/zclconf/go-cty/cty"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/block"
-	"github.com/tfsec/tfsec/pkg/provider"
-	"github.com/tfsec/tfsec/pkg/severity"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
+	"github.com/aquasecurity/tfsec/pkg/provider"
+	"github.com/aquasecurity/tfsec/pkg/severity"
 )
 
 // Result is a positive result for a security check. It encapsulates a code unique to the specific check it was raised
@@ -116,7 +116,7 @@ func (r *Result) WithAttributeAnnotation(attr block.Attribute) *Result {
 
 	switch typ {
 	case cty.String:
-		raw = fmt.Sprintf(`"%s"`, attr.Value().AsString())
+		raw = fmt.Sprintf("%q", attr.Value().AsString())
 		typeStr = "string"
 	case cty.Bool:
 		raw = fmt.Sprintf("%t", attr.Value().True())
@@ -133,7 +133,7 @@ func (r *Result) WithAttributeAnnotation(attr block.Attribute) *Result {
 			for _, value := range values {
 				switch value.Type() {
 				case cty.String:
-					strValues = append(strValues, fmt.Sprintf(`"%s"`, value.AsString()))
+					strValues = append(strValues, fmt.Sprintf("%q", value.AsString()))
 				case cty.Number:
 					strValues = append(strValues, fmt.Sprintf(`%f`, value.AsBigFloat()))
 				case cty.Bool:
